==> haskell-streaming-commons-0.2.2.1-51-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-streaming-commons.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 streaming-commons
version:              0.2.2.1
visibility:           public
id:                   streaming-commons-0.2.2.1-938fZlmr44gGmRrnowJ9yF
key:                  streaming-commons-0.2.2.1-938fZlmr44gGmRrnowJ9yF
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Emanuel Borsboom
homepage:             https://github.com/fpco/streaming-commons
synopsis:
    Common lower-level functions needed by various streaming data libraries

description:
    Provides low-dependency functionality commonly needed by various streaming data libraries, such as conduit and pipes.

category:             Data
abi:                  534473e7fe7c9f128d4c0c9d4d3bfe7a
exposed:              True
exposed-modules:
    Data.Streaming.ByteString.Builder
    Data.Streaming.ByteString.Builder.Buffer Data.Streaming.FileRead
    Data.Streaming.Filesystem Data.Streaming.Network
    Data.Streaming.Network.Internal Data.Streaming.Process
    Data.Streaming.Process.Internal Data.Streaming.Text
    Data.Streaming.Zlib Data.Streaming.Zlib.Lowlevel

hidden-modules:
    Data.Text.Internal.Unsafe.Char Data.Text.Internal.Unsafe.Shift
    Data.Text.Internal.Encoding.Utf8 Data.Text.Internal.Encoding.Utf16
    Data.Text.Internal.Encoding.Utf32

import-dirs:          /usr/lib/ghc-8.10.3/site-local/streaming-commons-0.2.2.1
library-dirs:         /usr/lib/ghc-8.10.3/site-local/streaming-commons-0.2.2.1
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.3/streaming-commons-0.2.2.1

hs-libraries:         HSstreaming-commons-0.2.2.1-938fZlmr44gGmRrnowJ9yF
depends:
    array-0.5.4.0 async-2.2.2-KHHcgxsnBk023FJgZiGQoA base-4.14.1.0
    bytestring-0.10.12.0 directory-1.3.6.0
    network-3.1.2.1-2sDMhNHJEdsLKPij0bexqJ process-1.6.9.0
    random-1.2.0-GUeG57tKzhUGrFomPkRIk2 stm-2.5.0.0 text-1.2.4.1
    transformers-0.5.6.2 unix-2.7.2.2
    zlib-0.6.2.2-KXEELA86DXm4dzFxfFE1wE

haddock-interfaces:
    /usr/share/doc/haskell-streaming-commons/html/streaming-commons.haddock

haddock-html:         /usr/share/doc/haskell-streaming-commons/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-streaming-commons-0.2.2.1-54-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-streaming-commons.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 streaming-commons
version:              0.2.2.1
visibility:           public
id:                   streaming-commons-0.2.2.1-AxlUv0Af44C74RTmGVbupD
key:                  streaming-commons-0.2.2.1-AxlUv0Af44C74RTmGVbupD
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Emanuel Borsboom
homepage:             https://github.com/fpco/streaming-commons
synopsis:
    Common lower-level functions needed by various streaming data libraries

description:
    Provides low-dependency functionality commonly needed by various streaming data libraries, such as conduit and pipes.

category:             Data
abi:                  359c66cea46cd3552bd3b58ba0ceeb96
exposed:              True
exposed-modules:
    Data.Streaming.ByteString.Builder
    Data.Streaming.ByteString.Builder.Buffer Data.Streaming.FileRead
    Data.Streaming.Filesystem Data.Streaming.Network
    Data.Streaming.Network.Internal Data.Streaming.Process
    Data.Streaming.Process.Internal Data.Streaming.Text
    Data.Streaming.Zlib Data.Streaming.Zlib.Lowlevel

hidden-modules:
    Data.Text.Internal.Unsafe.Char Data.Text.Internal.Unsafe.Shift
    Data.Text.Internal.Encoding.Utf8 Data.Text.Internal.Encoding.Utf16
    Data.Text.Internal.Encoding.Utf32

import-dirs:          /usr/lib/ghc-8.10.3/site-local/streaming-commons-0.2.2.1
library-dirs:         /usr/lib/ghc-8.10.3/site-local/streaming-commons-0.2.2.1
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.3/streaming-commons-0.2.2.1

hs-libraries:         HSstreaming-commons-0.2.2.1-AxlUv0Af44C74RTmGVbupD
depends:
    array-0.5.4.0 async-2.2.2-Ga7skT6sa0M3xMboL4eTgj base-4.14.1.0
    bytestring-0.10.12.0 directory-1.3.6.0
    network-3.1.2.1-IKBKB32QfOpBaCdBzK7XSA process-1.6.9.0
    random-1.2.0-30OhcoBMr9kCHjpVnmjVCw stm-2.5.0.0 text-1.2.4.1
    transformers-0.5.6.2 unix-2.7.2.2
    zlib-0.6.2.2-KXEELA86DXm4dzFxfFE1wE

haddock-interfaces:
    /usr/share/doc/haskell-streaming-commons/html/streaming-commons.haddock

haddock-html:         /usr/share/doc/haskell-streaming-commons/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
